@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """cssutils - CSS Cascading Style Sheets library for Python
 
-    Copyright (C) 2004-2009 Christof Hoeke
+    Copyright (C) 2004-2013 Christof Hoeke
 
     cssutils is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,7 @@ any rendering facilities!
 
 Based upon and partly implementing the following specifications :
 
-`CSS 2.1 <http://www.w3.org/TR/CSS21/>`__
+`CSS 2.1 <http://www.w3.org/TR/CSS2/>`__
     General CSS rules and properties are defined here
 `CSS 2.1 Errata  <http://www.w3.org/Style/css2-updates/CR-CSS21-20070719-errata.html>`__
     A few errata, mainly the definition of CHARSET_SYM tokens
@@ -36,12 +36,15 @@ Based upon and partly implementing the following specifications :
 `Namespaces <http://dev.w3.org/csswg/css3-namespace/>`__
     Added in v0.9.1, updated to definition in CSSOM in v0.9.4, updated in 0.9.5
     for dev version
+`CSS3 Module: Pages Media <http://www.w3.org/TR/css3-page/>`__
+    Most properties of this spec are implemented including MarginRules
 `Selectors <http://www.w3.org/TR/css3-selectors/>`__
     The selector syntax defined here (and not in CSS 2.1) should be parsable
     with cssutils (*should* mind though ;) )
 
 `DOM Level 2 Style CSS <http://www.w3.org/TR/DOM-Level-2-Style/css.html>`__
-    DOM for package css
+    DOM for package css. 0.9.8 removes support for CSSValue and related API,
+    see PropertyValue and Value API for now
 `DOM Level 2 Style Stylesheets <http://www.w3.org/TR/DOM-Level-2-Style/stylesheets.html>`__
     DOM for package stylesheets
 `CSSOM <http://dev.w3.org/csswg/cssom/>`__
@@ -67,7 +70,7 @@ which are well documented. Some minor extensions are provided as well.
 Please visit http://cthedot.de/cssutils/ for more details.
 
 
-Tested with Python 2.6 on Windows 7 mainly.
+Tested with Python 2.7.3 and 3.3 on Windows 8 64bit.
 
 
 This library may be used ``from cssutils import *`` which
@@ -88,11 +91,15 @@ Usage may be::
 __all__ = ['css', 'stylesheets', 'CSSParser', 'CSSSerializer']
 __docformat__ = 'restructuredtext'
 __author__ = 'Christof Hoeke with contributions by Walter Doerwald'
-__date__ = '$LastChangedDate:: 2010-11-27 20:13:08 +0100 #$:'
+__date__ = '$LastChangedDate::                            $:'
 
-VERSION = '0.9.7'
+VERSION = '0.9.10'
 
-__version__ = '%s $Id: __init__.py 2034 2010-11-27 19:13:08Z cthedot $' % VERSION
+__version__ = '%s $Id$' % VERSION
+
+import sys
+if sys.version_info < (2,6):
+    bytes = str
 
 import codec
 import os.path
@@ -101,13 +108,12 @@ import urlparse
 import xml.dom
 
 # order of imports is important (partly circular)
-from helper import Deprecated
+from . import util
 import errorhandler
 log = errorhandler.ErrorHandler()
 
 import css
 import stylesheets
-import util
 from parse import CSSParser
 
 from serialize import CSSSerializer
@@ -181,28 +187,9 @@ def parseUrl(*a, **k):
     return CSSParser().parseUrl(*a, **k)
 parseUrl.__doc__ = CSSParser.parseUrl.__doc__
 
-@Deprecated('Use cssutils.parseFile() instead.')
-def parse(*a, **k):
-    return parseFile(*a, **k)
-parse.__doc__ = CSSParser.parse.__doc__
-
-def parseStyle(cssText, encoding='utf-8'):
-    """Parse given `cssText` which is assumed to be the content of
-    a HTML style attribute.
-
-    :param cssText:
-        CSS string to parse
-    :param encoding:
-        It will be used to decode `cssText` if given as a (byte)
-        string.
-    :returns:
-        :class:`~cssutils.css.CSSStyleDeclaration`
-    """
-    if isinstance(cssText, str):
-        cssText = cssText.decode(encoding)
-    style = css.CSSStyleDeclaration()
-    style.cssText = cssText
-    return style
+def parseStyle(*a, **k):
+    return CSSParser().parseStyle(*a, **k)
+parseStyle.__doc__ = CSSParser.parseStyle.__doc__
 
 # set "ser", default serializer
 def setSerializer(serializer):
@@ -224,11 +211,6 @@ def getUrls(sheet):
     for importrule in (r for r in sheet if r.type == r.IMPORT_RULE):
         yield importrule.href
 
-    def getUrl(v):
-        if v.CSS_PRIMITIVE_VALUE == v.cssValueType and\
-           v.CSS_URI == v.primitiveType:
-                return v.getStringValue()
-
     def styleDeclarations(base):
         "recursive generator to find all CSSStyleDeclarations"
         if hasattr(base, 'cssRules'):
@@ -240,40 +222,29 @@ def getUrls(sheet):
 
     for style in styleDeclarations(sheet):
         for p in style.getProperties(all=True):
-            v = p.cssValue
-            if v.CSS_VALUE_LIST == v.cssValueType:
-                for item in v:
-                    u = getUrl(item)
-                    if u is not None:
-                        yield u
-            elif v.CSS_PRIMITIVE_VALUE == v.cssValueType:
-                u = getUrl(v)
-                if u is not None:
-                    yield u
+            for v in p.propertyValue:
+                if v.type == 'URI':
+                    yield v.uri
 
-def replaceUrls(sheet, replacer, ignoreImportRules=False):
+def replaceUrls(sheetOrStyle, replacer, ignoreImportRules=False):
     """Replace all URLs in :class:`cssutils.css.CSSImportRule` or
-    :class:`cssutils.css.CSSValue` objects of given `sheet`.
+    :class:`cssutils.css.CSSValue` objects of given `sheetOrStyle`.
 
-    :param sheet:
-        :class:`cssutils.css.CSSStyleSheet` which is changed
+    :param sheetOrStyle:
+        a :class:`cssutils.css.CSSStyleSheet` or a
+        :class:`cssutils.css.CSSStyleDeclaration` which is changed in place
     :param replacer:
-        a function which is called with a single argument `urlstring` which
-        is the current value of each url() excluding ``url(`` and ``)`` and
-        surrounding single or double quotes.
+        a function which is called with a single argument `url` which
+        is the current value of each url() excluding ``url(``, ``)`` and
+        surrounding (single or double) quotes.
     :param ignoreImportRules:
         if ``True`` does not call `replacer` with URLs from @import rules.
     """
-    if not ignoreImportRules:
-        for importrule in (r for r in sheet if r.type == r.IMPORT_RULE):
+    if not ignoreImportRules and not isinstance(sheetOrStyle,
+                                                css.CSSStyleDeclaration):
+        for importrule in (r for r in sheetOrStyle if r.type == r.IMPORT_RULE):
             importrule.href = replacer(importrule.href)
 
-    def setProperty(v):
-        if v.CSS_PRIMITIVE_VALUE == v.cssValueType and\
-           v.CSS_URI == v.primitiveType:
-                v.setStringValue(v.CSS_URI,
-                                 replacer(v.getStringValue()))
-
     def styleDeclarations(base):
         "recursive generator to find all CSSStyleDeclarations"
         if hasattr(base, 'cssRules'):
@@ -282,15 +253,15 @@ def replaceUrls(sheet, replacer, ignoreImportRules=False):
                     yield s
         elif hasattr(base, 'style'):
             yield base.style
+        elif isinstance(sheetOrStyle, css.CSSStyleDeclaration):
+            # base is a style already
+            yield base
 
-    for style in styleDeclarations(sheet):
+    for style in styleDeclarations(sheetOrStyle):
         for p in style.getProperties(all=True):
-            v = p.cssValue
-            if v.CSS_VALUE_LIST == v.cssValueType:
-                for item in v:
-                    setProperty(item)
-            elif v.CSS_PRIMITIVE_VALUE == v.cssValueType:
-                setProperty(v)
+            for v in p.propertyValue:
+                if v.type == v.URI:
+                    v.uri = replacer(v.uri)
 
 def resolveImports(sheet, target=None):
     """Recurcively combine all rules in given `sheet` into a `target` sheet.
@@ -320,8 +291,8 @@ def resolveImports(sheet, target=None):
         basesch, baseloc, basepath, basequery, basefrag = urlparse.urlsplit(targetbase)
         basepath, basepathfilename = os.path.split(basepath)
 
-        def replacer(url):
-            scheme, location, path, query, fragment = urlparse.urlsplit(url)
+        def replacer(uri):
+            scheme, location, path, query, fragment = urlparse.urlsplit(uri)
             if not scheme and not location and not path.startswith(u'/'):
                 # relative
                 path, filename = os.path.split(path)
@@ -329,7 +300,7 @@ def resolveImports(sheet, target=None):
                 return urllib.pathname2url(combined)
             else:
                 # keep anything absolute
-                return url
+                return uri
 
         return replacer
 
@@ -404,67 +375,11 @@ def resolveImports(sheet, target=None):
                           % rule.href, neverraise=True)
                 target.add(rule)
 
-
-
         else:
             target.add(rule)
 
     return target
 
 
-#def resolveVariables(sheet):
-#    """Replace all variable references with values defined in
-#    :class:`cssutils.css.CSSVariablesRule`. If no value can be found the
-#    variable reference is kept.
-#
-#    :param sheet:
-#        in this given :class:`cssutils.css.CSSStyleSheet` all variables
-#        are resolved.
-#    :returns: the sheet
-#    """
-#    def resolve(r):
-#        for p in r.style.getProperties(all=True):
-#            v = p.cssValue
-#
-#            if v.cssValueType == v.CSS_VALUE_LIST:
-#                newvalue = []
-#                for vi in v:
-#                    if vi.cssValueType == vi.CSS_VARIABLE:
-#                        if vi.value:
-#                            log.info(u'Replacing variable "%s" with %r' %
-#                                     (vi.name, vi.value), neverraise=True)
-#                            newvalue.append(vi.value)
-#                        else:
-#                            log.error(u'No value found for variable "%s"' %
-#                                     vi.name, neverraise=True)
-#                            newvalue.append(vi.cssText)
-#                    else:
-#                        newvalue.append(vi.cssText)
-#
-#                p.value = ' '.join(newvalue)
-#
-#            elif v.cssValueType == v.CSS_VARIABLE:
-#                if v.value:
-#                    log.info(u'Replacing variable "%s" with %r' %
-#                              (v.name, v.value), neverraise=True)
-#                    p.value = v.value
-#                else:
-#                    log.error(u'No value found for variable "%s"' %
-#                             v.name, neverraise=True)
-#
-#    for m in sheet.cssRules.rulesOfType(css.CSSRule.MEDIA_RULE):
-#        for r in m.cssRules.rulesOfType(css.CSSRule.STYLE_RULE):
-#            resolve(r)
-#
-#    for r in sheet.cssRules.rulesOfType(css.CSSRule.STYLE_RULE):
-#        resolve(r)
-#
-#    # remove @variables rules
-#    for r in sheet.cssRules.rulesOfType(css.CSSRule.VARIABLES_RULE):
-#        sheet.deleteRule(r)
-#
-#    return sheet
-
-
 if __name__ == '__main__':
     print __doc__
