@@ -12,7 +12,7 @@ open issues
 """
 __all__ = ['CSSProductions', 'MACROS', 'PRODUCTIONS']
 __docformat__ = 'restructuredtext'
-__version__ = '$Id: cssproductions.py 1855 2009-10-07 17:03:19Z cthedot $'
+__version__ = '$Id$'
 
 # a complete list of css3 macros
 MACROS = {
@@ -68,34 +68,37 @@ MACROS = {
 # used by cssutils, a mix of CSS3 and some CSS2.1 productions.
 # The productions are **ordered**:
 PRODUCTIONS = [
-    ('BOM', r'\xFEFF'), # will only be checked at beginning of CSS
+    # UTF8_BOM or UTF8_BOM_SIG will only be checked at beginning of CSS
+    ('BOM', '\xfe\xff|\xef\xbb\xbf'), 
     
     ('S', r'{s}+'), # 1st in list of general productions
     ('URI', r'{U}{R}{L}\({w}({string}|{url}*){w}\)'),
     ('FUNCTION', r'{ident}\('),
     ('UNICODE-RANGE', r'{U}\+[0-9A-Fa-f?]{1,6}(\-[0-9A-Fa-f]{1,6})?'),
     ('IDENT', r'{ident}'),
+    ('DIMENSION', r'{num}{ident}'),
+    ('PERCENTAGE', r'{num}\%'),
+    ('NUMBER', r'{num}'),
+    ('HASH', r'\#{name}'),
+    ('COMMENT', r'{comment}'), #r'\/\*[^*]*\*+([^/][^*]*\*+)*\/'),
     ('STRING', r'{string}'),
     ('INVALID', r'{invalid}'), # from CSS2.1
-    ('HASH', r'\#{name}'),
-    ('PERCENTAGE', r'{num}\%'),
-    ('DIMENSION', r'{num}{ident}'),
-    ('NUMBER', r'{num}'),
-    # valid ony at start so not checked everytime
-    #('CHARSET_SYM', r'@charset '), # from Errata includes ending space!
-    # checked specially if fullsheet is parsed
-    ('COMMENT', r'{comment}'), #r'\/\*[^*]*\*+([^/][^*]*\*+)*\/'),
     ('ATKEYWORD', r'@{ident}'), # other keywords are done in the tokenizer
-    ('CDO', r'\<\!\-\-'),
-    ('CDC', r'\-\-\>'),
     ('INCLUDES', '\~\='),
     ('DASHMATCH', r'\|\='),
     ('PREFIXMATCH', r'\^\='),
     ('SUFFIXMATCH', r'\$\='),
     ('SUBSTRINGMATCH', r'\*\='),
+    ('CDO', r'\<\!\-\-'),
+    ('CDC', r'\-\-\>'),
     ('CHAR', r'[^"\']') # MUST always be last
+    # valid ony at start so not checked everytime
+    #('CHARSET_SYM', r'@charset '), # from Errata includes ending space!
+    # checked specially if fullsheet is parsed
     ]
 
+
+
 class CSSProductions(object):
     """
     most attributes are set later
@@ -103,19 +106,19 @@ class CSSProductions(object):
     EOF = True
     # removed from productions as they simply are ATKEYWORD until 
     # tokenizing
-    CHARSET_SYM = 'CHARSET_SYM' 
-    FONT_FACE_SYM = 'FONT_FACE_SYM'
-    MEDIA_SYM = 'MEDIA_SYM'
-    IMPORT_SYM = 'IMPORT_SYM'
-    NAMESPACE_SYM = 'NAMESPACE_SYM'
-    PAGE_SYM = 'PAGE_SYM'
-    VARIABLES_SYM = 'VARIABLES_SYM'
+    CHARSET_SYM = u'CHARSET_SYM' 
+    FONT_FACE_SYM = u'FONT_FACE_SYM'
+    MEDIA_SYM = u'MEDIA_SYM'
+    IMPORT_SYM = u'IMPORT_SYM'
+    NAMESPACE_SYM = u'NAMESPACE_SYM'
+    PAGE_SYM = u'PAGE_SYM'
+    VARIABLES_SYM = u'VARIABLES_SYM'
 
 for i, t in enumerate(PRODUCTIONS):
     setattr(CSSProductions, t[0].replace('-', '_'), t[0])
     
 
 # may be enabled by settings.set
-_DXImageTransform = ('FUNCTION', 
-                     r'progid\:DXImageTransform\.Microsoft\..+\('
+_DXImageTransform = (u'FUNCTION', 
+                     ur'progid\:DXImageTransform\.Microsoft\..+\('
                      )
